@@ -5,7 +5,6 @@ import sqlite3
 import ssl
 
 import certifi
-import tldextract
 from colorama import Fore, Style
 from yarl import URL
 
@@ -22,7 +21,7 @@ FILE_FORMATS = {
         '.swf', '.avi', '.m4p', '.wmv',
         '.mp2', '.m4v', '.qt', '.mpe',
         '.mp4', '.flv', '.mov', '.mpg',
-        '.ogg', '.mkv'
+        '.ogg', '.mkv', '.mts'
     },
     'Audio': {
         '.mp3', '.flac', '.wav', '.m4a'
